==> haskell-byteable-0.1.1-24-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-byteable.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 byteable
version:              0.1.1
visibility:           public
id:                   byteable-0.1.1-6a8DqkMpvw66y0umFUx8qQ
key:                  byteable-0.1.1-6a8DqkMpvw66y0umFUx8qQ
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           vincent@snarc.org
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-byteable
synopsis:             Type class for sequence of bytes
description:
    Abstract class to manipulate sequence of bytes

    The use case of this class is abstracting manipulation of
    types that are just wrapping a bytestring with stronger and
    more meaniful name.

    Usual definition of those types are of the form: newtype MyType = MyType ByteString

category:             Data
abi:                  a2346f91070abfa5d4ba97d11617e5fe
exposed:              True
exposed-modules:      Data.Byteable
import-dirs:          /usr/lib/ghc-9.0.1/site-local/byteable-0.1.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/byteable-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-byteable
hs-libraries:         HSbyteable-0.1.1-6a8DqkMpvw66y0umFUx8qQ
depends:              base-4.15.0.0 bytestring-0.10.12.1
haddock-interfaces:   /usr/share/doc/haskell-byteable/html/byteable.haddock
haddock-html:         /usr/share/doc/haskell-byteable/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-byteable-0.1.1-25-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-byteable.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 byteable
version:              0.1.1
visibility:           public
id:                   byteable-0.1.1-F5eQFmfGgxkLWRm11Wu8en
key:                  byteable-0.1.1-F5eQFmfGgxkLWRm11Wu8en
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           vincent@snarc.org
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-byteable
synopsis:             Type class for sequence of bytes
description:
    Abstract class to manipulate sequence of bytes

    The use case of this class is abstracting manipulation of
    types that are just wrapping a bytestring with stronger and
    more meaniful name.

    Usual definition of those types are of the form: newtype MyType = MyType ByteString

category:             Data
abi:                  4c569184c0083e736c9f0f75adac81f6
exposed:              True
exposed-modules:      Data.Byteable
import-dirs:          /usr/lib/ghc-9.0.2/site-local/byteable-0.1.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/byteable-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-byteable
hs-libraries:         HSbyteable-0.1.1-F5eQFmfGgxkLWRm11Wu8en
depends:              base-4.15.1.0 bytestring-0.10.12.1
haddock-interfaces:   /usr/share/doc/haskell-byteable/html/byteable.haddock
haddock-html:         /usr/share/doc/haskell-byteable/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
